CADISHI executables — CADISHI 1.1.0 documentation

# CADISHI executables

The executables are accessible via the `cadishi` command.

The following documentation was automatically generated from the docstrings present in the source code files.

## cadishi.exe

Cadishi executables invoked via entry points in setup.py.

## cadishi.exe.cli

Cadishi main executable. Uses argparse to call further code.

This program is not intended to be called directly, rather a user executable cadishi is created via an entry_point in setup.py.

`cadishi.exe.cli.` `main`()

`cadishi.exe.cli.` `parse_args`()

  “Set up the cadishi command line interface using argparse.

  Individual cadishi commands and their arguments are set up next to their implementation via the configure_cli() functions.

## cadishi.exe.histograms

Distance histogram calculation driver, task parallel version.

Performs distance histogram calculations using cudh and pydh (or dist). The configuration is read from the parameter file histograms.{json,yaml}.

This program is not intended to be invoked directly. It is launched via cli.py which in turn is called as the cadishi command via an entry_point in setup.py.

`cadishi.exe.histograms.` `check_parameters`(histoparam)

  Check and sanitize input parameters for the histogram computation.

  Together with the <histograms_template.yaml> file, this function needs to be extended with each new parameter that is introduced.

`cadishi.exe.histograms.` `configure_cli`(subparsers)

  Attach a parser (specifying command name and flags) to the argparse subparsers object.

`cadishi.exe.histograms.` `main`(argparse_args)

`cadishi.exe.histograms.` `unexpectedShutdownHandler`(signum, frame)

  Singnal handler, to catch SIGUSR1 sent by child processes, and SIGTERM.

## cadishi.exe.unpack

Extract data from HDF5 to legacy (NumPy, JSON) text data.

unpack creates a directory structure from the HDF5 file’s group structure and writes the HDF5 datasets to text files located in the correct directories.

The main() function is to be called via cli.py.

`cadishi.exe.unpack.` `configure_cli`(subparsers)

  Attach a parser (specifying command name and flags) to the argparse subparsers object.

`cadishi.exe.unpack.` `main`(pargs)